@@ -11,7 +11,7 @@ if __name__ == '__main__':
         utilities.remove_time_version_stamp()
 
         # Get and unpack the LaTeX author resources from the publisher.
-        utilities.get_archive('https://epubs.siam.org/pb-assets/macros/standard/siamart_220329.zip', method = "cloudscraper")
+        utilities.get_archive('https://epubs.siam.org/pb-assets/macros/standard/siamart_220329.zip', method = "wget")
 
         # Get the separate style manual as well.
         utilities.get_file('https://epubs.siam.org/pb-assets/files/SIAM_STYLE_GUIDE_2019.pdf')
